diff --git a/src/mol-geo/representation/structure/visual/util/link.ts b/src/mol-geo/representation/structure/visual/util/link.ts
index f2f820ce237db37e09f88af3e603e627632654f2..865e52d99668e5d38d9c950928953049444e2253 100644
--- a/src/mol-geo/representation/structure/visual/util/link.ts
+++ b/src/mol-geo/representation/structure/visual/util/link.ts
@@ -92,8 +92,8 @@ export async function createLinkCylinderMesh(ctx: RuntimeContext, linkBuilder: L
         const f = flags(edgeIndex)
         meshBuilder.setGroup(edgeIndex)
 
-        if (LinkType.is(f, LinkType.Flag.MetallicCoordination)) {
-            // show metall coordinations with dashed cylinders
+        if (LinkType.is(f, LinkType.Flag.MetallicCoordination) || LinkType.is(f, LinkType.Flag.Hydrogen)) {
+            // show metall coordinations and hydrogen bonds with dashed cylinders
             cylinderProps.radiusTop = cylinderProps.radiusBottom = linkRadius / 3
             addFixedCountDashedCylinder(meshBuilder, va, vb, 0.5, 7, cylinderProps)
         } else if (o === 2 || o === 3) {